@@ -20,8 +20,10 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
-"""aiodagpi - An asynchronous python API wrapper for Dagpi : https://dagpi.tk"""
+"""aiodagpi - An asynchronous python API wrapper for Dagpi : https://dagpi.xyz"""
 
-__version__ = '0.2.6'
+from .client import aiodagpiclient
+
+__version__ = '0.2.9'
 __author__ = 'Raj Sharma <yrsharma@icloud.com>'
-__all__ = []
+__all__ = [aiodagpiclient]
